@@ -4,13 +4,13 @@
 sanitize_shape <- function(shape) {
 
     if (is.null(shape)) {
-        return(term + statistic ~ model)
+        shape <- term + statistic ~ model
     }
 
     checkmate::assert(
         checkmate::check_null(shape),
         checkmate::check_formula(shape),
-        checkmate::check_choice(shape, choices = c("rbind", "rcollapse"))
+        checkmate::check_choice(shape, choices = c("cbind", "rbind", "rcollapse"))
     )
 
     # interactions with ":" are used to combine columns
