@@ -5,10 +5,8 @@
 "Revert to `kableExtra` for one session:",
 "",
 "  options(modelsummary_factory_default = 'kableExtra')",
-"",
-"Change the default backend persistently:",
-"",
-"  config_modelsummary(factory_default = 'gt')",
+"  options(modelsummary_factory_latex = 'kableExtra')",
+"  options(modelsummary_factory_html = 'kableExtra')",
 "",
 "Silence this message forever:",
 "",
