@@ -7,6 +7,7 @@ models <- list(
   lm(hp ~ mpg + drat, mtcars))
 
 # latex threeparttable argument
+options(modelsummary_factory_latex = "kableExtra")
 tab1 <- modelsummary(models, output = "latex", stars = TRUE)
 tab2 <- modelsummary(models, output = "latex", threeparttable = TRUE, stars = TRUE)
 expect_false(grepl("threeparttable", tab1))
@@ -22,10 +23,7 @@ tab3 <- modelsummary(models,
   stars = TRUE,
   threeparttable = TRUE)
 expect_equivalent(sum(grepl("threeparttable", strsplit(tab3, "\n")[[1]])), 2)
-
-# stars_note < are protected by $ in latex
-tab <- modelsummary(models, stars = TRUE, output = "latex")
-expect_true(grepl("p $<$ 0.1", tab, fixed = TRUE))
+options(modelsummary_factory_latex = NULL)
 
 # output = latex_tabular
 expect_snapshot_print(
@@ -40,4 +38,4 @@ base$fe2 = rep(letters[1:5], 30)
 base$fe3 = rep(letters[1:5], 30)
 est_comb = feols(y ~ x1 | fe1 + fe2 + fe3, data = base, cluster = "fe1^fe2")
 tab <- modelsummary(est_comb, output = "latex")
-expect_true(grepl("circum\\{\\}", tab))
\ No newline at end of file
+expect_true(grepl("circum\\{\\}", tab))
